==> fannypack-2.5.1.tgz: package/es/Checkbox/Checkbox.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';

import Text from '../Text';
import _Checkbox, { CheckboxIcon, HiddenCheckbox } from './styled';

var Checkbox = function Checkbox(_ref) {
  var a11yLabel = _ref.a11yLabel,
      autoFocus = _ref.autoFocus,
      checked = _ref.checked,
      className = _ref.className,
      defaultValue = _ref.defaultValue,
      disabled = _ref.disabled,
      id = _ref.id,
      isRequired = _ref.isRequired,
      label = _ref.label,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      name = _ref.name,
      state = _ref.state,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, ['a11yLabel', 'autoFocus', 'checked', 'className', 'defaultValue', 'disabled', 'id', 'isRequired', 'label', 'onBlur', 'onChange', 'onFocus', 'name', 'state', 'value']);

  return React.createElement(
    _Checkbox,
    _extends({
      'aria-describedby': 'label',
      'aria-invalid': state === 'danger',
      'aria-label': a11yLabel,
      'aria-required': isRequired
    }, props),
    React.createElement(HiddenCheckbox, {
      autoFocus: autoFocus,
      checked: checked,
      defaultValue: defaultValue,
      disabled: disabled,
      id: id,
      onBlur: onBlur,
      onChange: onChange,
      onFocus: onFocus,
      name: name,
      state: state,
      type: 'checkbox',
      value: value
    }),
    React.createElement(CheckboxIcon, { state: state }),
    React.createElement(
      Text,
      { id: 'label', marginLeft: 'xxsmall' },
      label
    )
  );
};

Checkbox.defaultProps = {
  a11yLabel: null,
  autoFocus: false,
  checked: undefined,
  className: null,
  defaultValue: undefined,
  disabled: false,
  id: null,
  isRequired: false,
  onBlur: null,
  onChange: null,
  onFocus: null,
  name: null,
  state: null,
  value: undefined
};

export default Checkbox;

==> fannypack-2.8.0.tgz: package/es/Checkbox/Checkbox.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';

import Text from '../Text';
import _Checkbox, { CheckboxIcon, HiddenCheckbox } from './styled';

var Checkbox = function Checkbox(_ref) {
  var autoFocus = _ref.autoFocus,
      checked = _ref.checked,
      className = _ref.className,
      defaultChecked = _ref.defaultChecked,
      disabled = _ref.disabled,
      id = _ref.id,
      isRequired = _ref.isRequired,
      label = _ref.label,
      onBlur = _ref.onBlur,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      name = _ref.name,
      state = _ref.state,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, ['autoFocus', 'checked', 'className', 'defaultChecked', 'disabled', 'id', 'isRequired', 'label', 'onBlur', 'onChange', 'onFocus', 'name', 'state', 'value']);

  return React.createElement(
    _Checkbox,
    _extends({
      'aria-describedby': 'label',
      'aria-invalid': state === 'danger',
      'aria-label': label,
      'aria-required': isRequired
    }, props),
    React.createElement(HiddenCheckbox, {
      autoFocus: autoFocus,
      checked: checked,
      defaultChecked: defaultChecked,
      disabled: disabled,
      id: id,
      onBlur: onBlur,
      onChange: onChange,
      onFocus: onFocus,
      name: name,
      state: state,
      type: 'checkbox',
      value: value
    }),
    React.createElement(CheckboxIcon, { state: state }),
    React.createElement(
      Text,
      { id: 'label', marginLeft: 'xxsmall' },
      label
    )
  );
};

Checkbox.defaultProps = {
  autoFocus: false,
  checked: undefined,
  className: null,
  defaultChecked: undefined,
  disabled: false,
  id: null,
  isRequired: false,
  onBlur: null,
  onChange: null,
  onFocus: null,
  name: null,
  state: null,
  value: undefined
};

export default Checkbox;
